//
//  OnePassViewController.m
//  Demo
//
//  Created by edz on 2020/12/22.
//  Copyright © 2020 ryw. All rights reserved.
//

#import "OnePassViewController.h"
#import <KSCLoginSDK/KSCLoginSDK.h>
#import "ResultViewController.h"
#import "KSCSDKUntils.h"
#import "KSCProgressHUD.h"
#import "UIView+KSC.h"

@interface OnePassViewController ()
@property (weak, nonatomic) IBOutlet UITextField *phoneNumberTF;


@end

@implementation OnePassViewController

- (void)viewDidLoad {
    [super viewDidLoad];

    //测试代码
//    self.phoneNumberTF.text = @"18701463408";
//    self.phoneNumberTF.text = @"13269521286";
//    self.phoneNumberTF.text = @"15313972902";
    
    NSAttributedString *attrString = [[NSAttributedString alloc] initWithString:@"输入本机号码" attributes: @{NSForegroundColorAttributeName:ssRGBHex(0xC3C3C3), NSFontAttributeName:self.phoneNumberTF.font }
                                      ];
    self.phoneNumberTF.attributedPlaceholder = attrString;
}


- (void)viewWillAppear:(BOOL)animated {
    [super viewWillAppear:animated];
    
    self.navigationController.navigationBar.hidden = YES;
}
- (IBAction)nativeAuthentication:(UIButton *)sender {
    /*
     **************************    ！！！！！！！！！！！！
     这里要清除一下缓存，防止双卡的手机，本机认证和一键登录不是一个卡，否则会出现验证失败的问题
     **************************    ！！！！！！！！！！！！
     */
    [KSCSDKLogin delectScrip];
    
    sender.enabled = NO;

    NSString *toastStr = [KSCSDKUntils getNoNetworkToastStr];
    if (![toastStr isEqualToString:@""]) {
        sender.enabled = YES;
        [KSCProgressHUD showToastWithMessage:toastStr];
        return;
    }
    
    NSString *phoneNumber = self.phoneNumberTF.text;
    phoneNumber = [phoneNumber stringByReplacingOccurrencesOfString:@" " withString:@""];
    NSString *toastString = [self checkPhoneNumFormat:phoneNumber];
    if ([toastString isEqualToString:@""]) {
        sender.enabled = YES;
        NSString *toastStr = [KSCSDKUntils getNoNetworkToastStr];
        if (![toastStr isEqualToString:@""]) {
            [KSCProgressHUD showToastWithMessage:toastStr];
            return;
        }
        // 获取token未成功时，建议加载进度条
        [KSCProgressHUD showLoadingHUDWithMessage:nil];
        sender.enabled = NO;
        
        //获取token
        [KSCSDKLogin ksc_mobileAuthCompletion:^(NSDictionary * _Nonnull result) {
            [KSCProgressHUD hideAllHUD];
            sender.enabled = YES;
            [self.phoneNumberTF resignFirstResponder];
            NSString *resultCode = result[@"resultCode"];
            
            NSMutableDictionary *resultDic = [NSMutableDictionary dictionaryWithDictionary:result];
            if ([resultCode isEqualToString:SUCCESSCODE]) {
                NSString *phoneNumStr = self.phoneNumberTF.text;
                resultDic[KSC_PARMS_IPHONE_KEY] = phoneNumStr;
                /**
                 =======================================================================
                 !!!!!!!!  到这里SDK已经成功获取到token和手机号码了，demo是跳转到“结果页面”，之后的业务就需要和己公司的服务端的同学去对接
                 =======================================================================
                 */
                [self pushResultVCWithDic:resultDic];
            } else {
                [KSCProgressHUD showToastWithMessage:@"请开启移动网络"];
            }
        }];
    } else {
        sender.enabled = YES;
        [self.phoneNumberTF ksc_shake:9 witheDelta:2.f speed:0.1 completion:nil];
        [KSCProgressHUD showToastWithMessage:toastString];
    }
}


- (void)pushResultVCWithDic:(NSMutableDictionary *)dic {
    UIStoryboard *storyboard = [UIStoryboard storyboardWithName:@"Main" bundle:[NSBundle mainBundle]];
    ResultViewController *vc = [storyboard instantiateViewControllerWithIdentifier:@"result"];
    vc.data = dic;
    vc.isOneLogin = NO;
    [self.navigationController pushViewController:vc animated:YES];
}

- (NSString *)checkPhoneNumFormat:(NSString *)num {
    /**
     * 手机号码
     * 移动：134[0-8],135,136,137,138,139,147,148,150,151,152,157,158,159,172,178,182,183,184,187,188,198
     * 联通：130,131,132,145,146,152,155,156,166,171,175,176,185,186
     * 电信：133,1349,153,173,174,177,180,181,189,199
     */

    /**
     * 宽泛的手机号过滤规则  11位，数字
     */
    NSString * MOBILE = @"^1([3-9])\\d{9}$";

    /**
     * 虚拟运营商: Virtual Network Operator
     * 不支持
     */
    NSString * VNO = @"^170\\d{8}$";

    /**
     * 中国移动：China Mobile
     * 134[0-8],135,136,137,138,139,147,150,151,152,157,158,159,172,178,182,183,184,187,188
     */

    NSString * CM = @"^1(34[0-8]|(3[5-9]|4[78]|5[0-27-9]|7[28]|8[2-478]|98)\\d)\\d{7}$";

    /**
     * 中国联通：China Unicom
     * 130,131,132,152,155,156,176,185,186
     */

    NSString * CU = @"^1(3[0-2]|45|5[256]|7[156]|8[56])\\d{8}$";

    /**
     * 中国电信：China Telecom
     * 133,1349,153,173,177,180,181,189
     */

    NSString * CT = @"^1((33|53|7[347]|8[019]|99)[0-9]|349)\\d{7}$";

    NSPredicate *regexTestMobile = [NSPredicate predicateWithFormat:@"SELF MATCHES %@", MOBILE];

    //根据需求暂时去掉 加上170的判断
    NSPredicate *regexTestVNO = [NSPredicate predicateWithFormat:@"SELF MATCHES %@", VNO];

    NSPredicate *regexTestCM = [NSPredicate predicateWithFormat:@"SELF MATCHES %@", CM];

    NSPredicate *regexTestCU = [NSPredicate predicateWithFormat:@"SELF MATCHES %@", CU];

    NSPredicate *regexTestCT = [NSPredicate predicateWithFormat:@"SELF MATCHES %@", CT];

    if ([regexTestMobile evaluateWithObject:num] == YES) {
        if (
            ([regexTestCM evaluateWithObject:num] == YES) ||
            ([regexTestCT evaluateWithObject:num] == YES) ||
            ([regexTestCU evaluateWithObject:num] == YES) ||
            ([regexTestVNO evaluateWithObject:num] == YES)
            ) {
            return @"";//格式正确
        } else {
            return @"手机号格式不正确";
        }
    } else {
        return @"请输入正确的手机号码";
    }
}

- (void)touchesBegan:(NSSet<UITouch *> *)touches withEvent:(UIEvent *)event {
    [self.phoneNumberTF resignFirstResponder];
}

- (IBAction)backBtnClick {
    [self.navigationController popViewControllerAnimated:YES];
}

@end
