//
//  ViewController.m
//  Demo
//
//  Created by edz on 2020/12/21.
//  Copyright © 2020 ryw. All rights reserved.
//

#import "ViewController.h"
#import <KSCLoginSDK/KSCLoginSDK.h>

#import "OnePassViewController.h"
#import "ResultViewController.h"

#import "KSCSDKUntils.h"
#import "Common.h"
#import "KSCProgressHUD.h"


@interface ViewController ()

//模型的UI属性
@property (nonatomic,assign) BOOL authWindow;
@property (nonatomic,assign) BOOL edgeWindow;
@property (nonatomic,assign) BOOL shouldAuthorVCStatusBarWhite;

//根据横竖屏 显示对应的布局 需求更改暂时不支持横屏，但是在storyboard里面有对应的UI已经写完（默认hidden = YES），如果有需要可以进行参考
@property (weak, nonatomic) IBOutlet UIView *portraitShowView;
@property (weak, nonatomic) IBOutlet UIView *landscapeShowView;

@property (weak, nonatomic) IBOutlet UIButton *fullScreenBtn;
@property (weak, nonatomic) IBOutlet UIButton *windowBtn;

@property (weak, nonatomic) IBOutlet NSLayoutConstraint *bottomViewH;


@end

@implementation ViewController

#pragma mark - lifeCycle
- (void)viewDidLoad {
    [super viewDidLoad];
    if (kScreenHeight <= 568) { //5s单独处理 不然按钮会超过白色部分
        self.bottomViewH.constant = -20;
    }
}

/*
 //根据横竖屏 显示对应的布局 需求更改暂时不支持横屏，但是在storyboard里面有对应的UI已经写完（默认hidden = YES），如果有需要可以进行参考
 - (void)viewWillLayoutSubviews {
     BOOL isLandscape = [UIApplication sharedApplication].statusBarOrientation == UIInterfaceOrientationLandscapeLeft || [UIApplication sharedApplication].statusBarOrientation == UIInterfaceOrientationLandscapeRight;
     if (isLandscape) {
         self.landscapeShowView.hidden = NO;
         self.portraitShowView.hidden = YES;
     } else {
         self.landscapeShowView.hidden = YES;
         self.portraitShowView.hidden = NO;
     }
 }
 */


- (void)viewWillAppear:(BOOL)animated {
    [super viewWillAppear:animated];
    self.navigationController.navigationBar.hidden = YES;
    self.windowBtn.enabled = YES;
    self.fullScreenBtn.enabled = YES;
}

#pragma mark - action
- (IBAction)oneLoginFullScreenBtnClick:(UIButton *)sender {
    self.authWindow = NO;
    [self oneLoginWithBtn:sender];
}

- (IBAction)oneLoginWindowBtnClick:(UIButton *)sender {
    self.authWindow = YES;
    [self oneLoginWithBtn:sender];
}

- (IBAction)nativeAuthenticationBtnClick {
    UIStoryboard *storyboard = [UIStoryboard storyboardWithName:@"Main" bundle:[NSBundle mainBundle]];
    OnePassViewController *controller = [storyboard instantiateViewControllerWithIdentifier:@"OnePassViewController"];
    if (controller) {
        [self.navigationController pushViewController:controller animated:YES];
    }
}

#pragma mark - private
/** 调用SDK 目的是去获取token */
- (void)oneLoginWithBtn:(UIButton *)btn {
    
    NSString *toastStr = [KSCSDKUntils getNoNetworkToastStr];
    if (![toastStr isEqualToString:@""]) {
        [KSCProgressHUD showToastWithMessage:toastStr];
        return;
    }
    btn.enabled = NO;
    // 在SDK内部预取号未成功时，建议加载进度条
    [KSCProgressHUD showLoadingHUDWithMessage:nil];
    
    KSCCustomModel *model = [self configModel];
    //1.先获取预取号
    [KSCSDKLogin ksc_getPhoneNumberCompletion:^(NSDictionary * _Nonnull result) {
        //授权页 点击一键登录的时候没网的次数
        __block int count = 5;
        NSString *resultCode = result[@"resultCode"];
        [KSCProgressHUD hideAllHUD];
        [KSCSDKLogin delectScrip];
        if ([resultCode isEqualToString:SUCCESSCODE]) {
            dispatch_after(dispatch_time(DISPATCH_TIME_NOW, (int64_t)(1.0 * NSEC_PER_SEC)), dispatch_get_main_queue(), ^{
                btn.enabled = YES;
            });
            // 加载进度条
            [KSCProgressHUD showLoadingHUDWithMessage:nil];
            
            if (self.authWindow) {
                [self showMenBanView:YES];
            }
            //2.在预取号成功的回调里再调用调起授权页的方法
            [KSCSDKLogin ksc_getAuthorizationWithModel:model complete:^(id  _Nonnull sender) {
                //没开蜂窝网络 提示5次
                if (count > 0) {
                    NSString *toastStr = [KSCSDKUntils getNoNetworkToastStr];
                    if (![toastStr isEqualToString:@""]) {
                        count--;
                        [KSCProgressHUD showToastWithMessage:toastStr];
                        return;
                    }
                }
               
                [KSCProgressHUD hideAllHUD];
                NSString *resultCode = sender[@"resultCode"];
                NSMutableDictionary *result = [NSMutableDictionary dictionaryWithDictionary:sender];
                if ([resultCode isEqualToString:SUCCESSCODE]) {
                    NSString *toastStr = [KSCSDKUntils getNoNetworkToastStr];
                    if (![toastStr isEqualToString:@""]) {
                        [KSCProgressHUD showToastWithMessage:toastStr];
                        return;
                    }
                    result[@"result"] = @"获取token成功";
                    NSLog(@"==++++===1111111111111111%@", sender);
                    /**
                     =======================================================================
                     !!!!!!!!  到这里SDK已经成功获取到token了，demo是跳转到“结果页面”，之后的业务就需要和己公司的服务端的同学去对接
                     =======================================================================
                     */
                    [KSCSDKLogin ksc_ua_dismissViewControllerAnimated:YES completion:^{
                        [self pushResultVCWithDic:result];
                    }];
                    
                } else if(![resultCode isEqualToString:@"200087"]){
                    result[@"result"] = @"获取token失败";
                }else{
                }
            }];
        } else {
            btn.enabled = YES;
            [KSCProgressHUD showToastWithMessage:@"预取号失败，初始化SDK失败，请重启APP"];
        }
    }];
//    [KSCSDKLogin delectScrip];
}


- (void)showMenBanView:(BOOL)show {
    if (show) {
        //蒙版效果
        UIView *blackView = [[UIView alloc] initWithFrame:self.view.bounds];
        blackView.tag = 888;
        blackView.backgroundColor = ssRGBHexAlpha(0x000000, 0.4);
        [self.view addSubview:blackView];
        
        
        
    } else {
        UIView *blackView = [self.view viewWithTag:888];
        [blackView removeFromSuperview];
    }
}
- (void)pushResultVCWithDic:(NSMutableDictionary *)dic {
    //关闭蒙版效果
    if (self.authWindow) {
        [self showMenBanView:NO];
    }
    UIStoryboard *storyboard = [UIStoryboard storyboardWithName:@"Main" bundle:[NSBundle mainBundle]];
    ResultViewController *vc = [storyboard instantiateViewControllerWithIdentifier:@"result"];
    vc.data = dic;
    vc.isOneLogin = YES;
    [self.navigationController pushViewController:vc animated:YES];
}

- (UIButton *)setBtnWith:(NSString *)imageName{
    UIButton *btn = [[UIButton alloc]init];
    [btn setImage:[UIImage imageNamed:imageName] forState:(UIControlStateNormal)];
    [btn setImageEdgeInsets:UIEdgeInsetsMake(20, 20, 20, 20)];
    return btn;
}

- (void)dismissAuthVC {
    //关闭蒙版效果
    if (self.authWindow) {
        [self showMenBanView:NO];
    }
    [self dismissViewControllerAnimated:YES completion:nil];
}

/** 配置模型 主要是UI显示 */
- (KSCCustomModel *)configModel {
    //获取运营商
    NSString *carrierStr = [KSCSDKLogin carrierStr];
    
    KSCCustomModel *model = [[KSCCustomModel alloc] init];
    
    //1、当前VC 必传 不传会提示调用失败
    model.currentVC = self;
#pragma mark ---------------------- 竖屏布局 --------------------
    model.statusBarStyle = self.shouldAuthorVCStatusBarWhite ? UIStatusBarStyleLightContent : UIStatusBarStyleDefault;
    
    
    if (!self.authWindow) {
#pragma mark 常量设置
        CGFloat servylabelH = 20;
        CGFloat logBtnH = 58;
        CGFloat logBtnW = 278;
        CGFloat privacyH = 33;
        CGFloat btnsViewH = 79;
        CGFloat otherLoginLabelH = 20;
        //    CGFloat otherLoginBtnH = 49;
        CGFloat btnsW = 219;
        //    CGFloat btnWH = 24.5;
        CGFloat btnWH = 40;
        
        //logo宽高
        CGFloat logoImageVWH = 77;
        //号码label两边的间隔
        CGFloat marge = kIPhone6RatioValue(10);
        //登录按钮下面的 间隔
        CGFloat loginBtnBottomMarge = kIPhone6RatioValue(10);
        //登录按钮上面的 间隔
        CGFloat loginBtnTTopMarge = kIPhone6RatioValue(20);
        //登录按钮从底部算的 偏移量
        NSNumber *numberOffsetY_B = @(kIPhone6RatioValue(444));
        //自定义登录3个按钮上面的 间隔
        CGFloat btnsTopMarge = kIPhone6RatioValue(150);
        //自定义登录3个按钮和上面label 间隔
        CGFloat otherLoginLabelBottomMarge = 20;
        //自定义登录3个按钮和上面label 间隔
        CGFloat otherBtnsMarge = (btnsW - 3 * btnWH) / 2 ;
        
        NSNumber *logBtnOriginLR = @((kScreenWidth - logBtnW)/2.0);
        //    NSNumber *logBtnOriginLR = @(kIPhone6RatioValue(52.5));
        NSNumber *appPrivacyOriginLR = @(52.5);
        NSNumber *appPrivacyOriginL = @(32.5);
        
#pragma mark 授权界面自定义控件View
        //2、授权界面自定义控件View的Block
        model.authViewBlock = ^(UIView *customView, CGRect numberFrame , CGRect loginBtnFrame,CGRect checkBoxFrame, CGRect privacyFrame) {
            CGFloat customViewW = customView.frame.size.width;
            CGFloat btnY = 0;
            if (IS_IPHONEX) {
                btnY = 44;
            } else {
                btnY = 25;
            }
            
            //1左上角的返回按钮
            UIButton *btn = [UIButton buttonWithType:UIButtonTypeCustom];
            [btn setImage:[UIImage imageNamed:@"返回"] forState:UIControlStateNormal];
            [btn setTitle:@"返回" forState:UIControlStateNormal];
            [btn setTitleColor:UIColor.blackColor forState:UIControlStateNormal];
            btn.titleLabel.font = [UIFont systemFontOfSize:17];
            CGFloat textColor = 80.0/255;
            btn.titleLabel.textColor = [UIColor colorWithRed:textColor green:textColor blue:textColor alpha:1];
            [btn addTarget:self action:@selector(dismissAuthVC) forControlEvents:UIControlEventTouchUpInside];
            btn.imageEdgeInsets = UIEdgeInsetsMake(0, -10, 0, 10);
            btn.titleEdgeInsets = UIEdgeInsetsMake(0, -18, 0, 18);
            btn.frame = CGRectMake(15, btnY, 72, 35);
            [customView addSubview:btn];
            
            //2.logo imageV
            UIImageView *logoImageV = [[UIImageView alloc] initWithImage:[UIImage imageNamed:@"一键登录-logo"]];
            CGFloat logoImageVY = numberFrame.origin.y - marge - logoImageVWH;
            logoImageV.frame = CGRectMake(0, logoImageVY, logoImageVWH, logoImageVWH);
            logoImageV.center = CGPointMake(customView.center.x, logoImageV.center.y);
            [customView addSubview:logoImageV];
            
            //3.运营商服务 label
            CGFloat servylabelY = CGRectGetMaxY(numberFrame) + marge;
            UILabel *servylabel = [[UILabel alloc] initWithFrame:CGRectMake(0, servylabelY, customViewW, servylabelH)];
            servylabel.center = CGPointMake(customView.center.x, servylabel.center.y);
            servylabel.text = [NSString stringWithFormat:@"%@提供认证服务", carrierStr];
            servylabel.textColor = ssRGBHex(0xA7A7A7);
            servylabel.textAlignment = NSTextAlignmentCenter;
            servylabel.font = [UIFont systemFontOfSize:14.0];
            [customView addSubview:servylabel];
            
            //4.3个自定义按钮
            CGFloat btnsViewY = CGRectGetMaxY(privacyFrame) + btnsTopMarge;
            UIView *btnsView = [[UIView alloc] initWithFrame:CGRectMake(0, btnsViewY, btnsW, btnsViewH)];
            btnsView.center = CGPointMake(customView.center.x, btnsView.center.y);
            
            UILabel *otherLoginLabel = [[UILabel alloc] initWithFrame:CGRectMake(0, 0, btnsView.frame.size.width, otherLoginLabelH)];
            otherLoginLabel.textAlignment = NSTextAlignmentCenter;
            otherLoginLabel.textColor = ssRGBHex(0xA7A7A7);
            otherLoginLabel.font = [UIFont systemFontOfSize:14.0];
            otherLoginLabel.text = @"其他方式登录";
            otherLoginLabel.center = CGPointMake(btnsView.frame.size.width / 2, otherLoginLabel.center.y);
            [btnsView addSubview:otherLoginLabel];
            
            for (int i = 0; i < 3; i++) {
                UIButton *otherBtn = [UIButton buttonWithType:UIButtonTypeCustom];
                otherBtn.frame = CGRectMake(i * (otherBtnsMarge + btnWH), otherLoginLabelH + otherLoginLabelBottomMarge, btnWH, btnWH);
                NSString *imageName = [NSString stringWithFormat:@"编组 %d", i + 2];
                [otherBtn setBackgroundImage:[UIImage imageNamed:imageName] forState:UIControlStateNormal];
                [otherBtn addTarget:self action:@selector(otherLoginBtnClick) forControlEvents:UIControlEventTouchUpInside];
                [btnsView addSubview:otherBtn];
            }
            
            [customView addSubview:btnsView];
        };
        
        //3、授权页面推出的动画效果
        model.presentType = KSCPresentationDirectionRight;
        /**4、授权界面背景图片*/
        model.authPageBackgroundImage = [UIImage imageNamed:@"背景2"];
        
#pragma mark 登录按钮修改设置
        //6、登录按钮修改
        model.logBtnText = [[NSAttributedString alloc]initWithString:@"一键登录" attributes:@{NSForegroundColorAttributeName:[UIColor whiteColor]}];
        //8、按钮左右边距
        model.logBtnOriginLR = @[logBtnOriginLR, logBtnOriginLR];
        //9、登录按钮的高h
        model.logBtnHeight = logBtnH;
        //10、授权界面登录按钮三种状态
        UIImage *norMal = [UIImage imageNamed:@"编组"];
        /**10、登录按钮背景图片添加到数组(顺序如下)
         @[激活状态的图片, 失效状态的图片, 高亮状态的图片]
        */
        model.logBtnImgs = @[norMal,norMal,norMal];
        /**11、登录按钮高距离底部的高度  和7比   11的优先级高*/
        model.logBtnOffsetY_B = @(numberOffsetY_B.intValue - marge - loginBtnTTopMarge - servylabelH - logBtnH);
        
#pragma mark 号码框设置
        //12、号码栏字体大小
        model.numberTextAttributes =  @{NSForegroundColorAttributeName:ssRGBHex(0xE23F3F),NSFontAttributeName:[UIFont boldSystemFontOfSize:18]};
        //13、号码栏X偏移量
        //    model.numberOffsetX = @20;
        //14、号码栏Y偏移量
        model.numberOffsetY_B = numberOffsetY_B;
        
#pragma mark 隐私条款
        //16、隐私条款uncheckedImg选中图片
        model.uncheckedImg = nil;
        //17、隐私条款chexBox选中图片
        model.checkedImg = nil;
        //18、复选框大小（只能正方形）必须大于12*/
        model.checkboxWH = @15;
        //*19、隐私条款（包括check框）的左右边距*/
        model.appPrivacyOriginLR = @[appPrivacyOriginL, appPrivacyOriginLR];
        //20、隐私的内容模板
        model.appPrivacyDemo = [[NSAttributedString alloc] initWithString:@"点击登录即同意&&默认&&并授权本Demo获取本机号码" attributes:
                                @{
                                    NSFontAttributeName:[UIFont fontWithName:@"PingFang-SC-Regular" size:12],
                                    NSForegroundColorAttributeName:ssRGBHex(0x404040)}];
        
        
        //21、隐私条款默认协议是否开启书名号
        model.privacySymbol = YES;
        //24、隐私条款名称颜色（协议）
        model.privacyColor = ssRGBHex(0xE23F3F);
        /**27、隐私条款Y偏移量(注:此属性为与屏幕底部的距离)*/
        model.privacyOffsetY_B = @(model.logBtnOffsetY_B.intValue - loginBtnBottomMarge - privacyH);
        //26、隐私条款check框默认状态
        model.privacyState = YES;
        /**40、未勾选隐私条款提示的自定义提示文案，提示功能默认关闭，该属性被合法赋值（非空，且最大长度为100的字符串）后打开提示功能。*/
        model.checkTipText = @"请勾选同意服务条款";
        
        //28、web协议界面导航返回图标(尺寸根据图片大小)
        model.webNavReturnImg = [UIImage imageNamed:@"close2"];
        //29、web协议界面导航标题字体属性设置
        model.webNavTitleAttrs = @{NSForegroundColorAttributeName: [UIColor redColor], NSFontAttributeName: [UIFont systemFontOfSize:16]};
        //30、web协议界面导航标题栏颜色
        model.webNavColor = [UIColor redColor];
        
        /**39、模态展示样式设置属性
         注意：
         在窗口模式，即authWindow = YES时。modalPresentationStyle需要设置为UIModalPresentationOverFullScreen或者UIModalPresentationCustom；
         在边缘弹窗模式，即设置了controllerSize时，modalPresentationStyle需要设置为UIModalPresentationCustom；
         */
        model.modalPresentationStyle = UIModalPresentationOverFullScreen;
        model.faceOrientation = UIInterfaceOrientationPortrait;
    }
    #pragma mark ----------------------弹窗竖屏:(温馨提示:由于受屏幕影响，小屏幕（5S,5E,5）需要改动字体和另自适应和布局)--------------------
    else {
        BOOL isSmallScreen = UIScreen.mainScreen.bounds.size.height < 375.f;
#pragma mark 常量设置
        CGFloat servylabelH = 20;
        CGFloat logBtnH = 40;
        CGFloat windowH = 361;
        CGFloat windowW = 330;
        CGFloat yanzhenlabelH = 22;
        
        //logo宽高
        CGFloat logoImageVWH = 64;
        //号码label两边的间隔
        CGFloat marge = kIPhone6RatioValue(10);
        //登录按钮从底部算的 偏移量
        NSNumber *logBtnOffsetY_B = nil;
        if (kScreenHeight == 896) { // XR XSMAX 11 11PROMAX
            logBtnOffsetY_B = @130;
        }
        else if (kScreenHeight == 812) { // X XS 11PRO
            logBtnOffsetY_B = @100;
        }
        else {
            logBtnOffsetY_B = @(kIPhone6RatioValue(80));
        }
//        NSNumber *logBtnOffsetY_B = IS_IPHONEX ? @130 : @(kIPhone6RatioValue(80));
//        NSNumber *privacyOffsetY_B = IS_IPHONEX ? @65 :@(kIPhone6RatioValue(25));
        
        NSNumber *privacyOffsetY_B = nil;
        if (kScreenHeight == 896) { // XR XSMAX 11 11PROMAX
            privacyOffsetY_B = @65;
        }
        else if (kScreenHeight == 812) { // X XS 11PRO
            privacyOffsetY_B = @(40);
        }
        else {
            privacyOffsetY_B = @(kIPhone6RatioValue(25));
        }
        
        CGFloat logoImageVy = kIPhone6RatioValue(40);
//        NSNumber *numberOffsetY_B = @(kIPhone6RatioValue(165));
        NSNumber *numberOffsetY_B = nil;
        if (kScreenHeight == 812) {  // X XS 11PRO
            numberOffsetY_B = @(188);
        } else {
            numberOffsetY_B = @(kIPhone6RatioValue(165));
        }
        
        
        NSNumber *logBtnOriginLR = @(30);
        NSNumber *appPrivacyOriginL = @(10);
        NSNumber *appPrivacyOriginLR = @(20);
        
        model.authWindow = YES;
        /**39、模态展示样式设置属性
         注意：
         在窗口模式，即authWindow = YES时。modalPresentationStyle需要设置为UIModalPresentationOverFullScreen或者UIModalPresentationCustom；
         */
        model.modalPresentationStyle = UIModalPresentationCustom;
        model.cornerRadius = 8;
        model.modalTransitionStyle = UIModalTransitionStyleFlipHorizontal;
        
         //屏幕宽高比按照比例缩放
        model.scaleH = kIPhone6RatioValue(windowH);
        model.scaleW = kAutolayout6(windowW);
        if (kScreenHeight > 736) {
            model.scaleH = 0.45;
        } else {
            model.scaleH = 0.5;
        }
        model.scaleW = 0.88;
        
#pragma mark 登录按钮修改设置
        //6、登录按钮修改
        model.logBtnText = [[NSAttributedString alloc]initWithString:@"一键登录" attributes:@{NSForegroundColorAttributeName:[UIColor whiteColor]}];
        //8、按钮左右边距
        model.logBtnOriginLR = @[logBtnOriginLR, logBtnOriginLR];
        //9、登录按钮的高h
        model.logBtnHeight = logBtnH;
        //10、授权界面登录按钮三种状态
        UIImage *norMal = [UIImage imageNamed:@"一键登录"];
        model.logBtnImgs = @[norMal,norMal,norMal];
        /**11、登录按钮高距离底部的高度  和7比   11的优先级高*/
        model.logBtnOffsetY_B = logBtnOffsetY_B;
                
#pragma mark 号码框设置
        //12、号码栏字体大小
        model.numberTextAttributes =  @{NSForegroundColorAttributeName:ssRGBHex(0x222222),NSFontAttributeName:[UIFont systemFontOfSize:16]};
        //14、号码栏Y偏移量
        model.numberOffsetY_B = numberOffsetY_B;
        
#pragma mark 隐私条款
//        //16、隐私条款uncheckedImg选中图片
//        model.uncheckedImg = [UIImage imageNamed:@"nor"];
//        //17、隐私条款chexBox选中图片
//        model.checkedImg = [UIImage imageNamed:@"sel"];
//        //18、复选框大小（只能正方形）必须大于12*/
//        model.checkboxWH = @14;
        //*19、隐私条款（包括check框）的左右边距*/
        model.appPrivacyOriginLR = @[appPrivacyOriginL, appPrivacyOriginLR];
        //20、隐私的内容模板
        model.appPrivacyDemo = [[NSAttributedString alloc] initWithString:@"点击登录即同意&&默认&&并授权本Demo获取本机号码" attributes:
                                @{
                                    NSFontAttributeName:[UIFont fontWithName:@"PingFang-SC-Regular" size:14],
                                    NSForegroundColorAttributeName:ssRGBHex(0x959595)}];
         
        //21、隐私条款默认协议是否开启书名号
        model.privacySymbol = YES;
        //24、隐私条款名称颜色（协议）
        model.privacyColor = ssRGBHex(0xE23F3F);
        /**27、隐私条款Y偏移量(注:此属性为与屏幕底部的距离)*/
//        model.privacyOffsetY_B = @(model.logBtnOffsetY_B.intValue - loginBtnBottomMarge - privacyH);
        model.privacyOffsetY_B = privacyOffsetY_B;
        //26、隐私条款check框默认状态
        model.privacyState = YES;
        /**40、未勾选隐私条款提示的自定义提示文案，提示功能默认关闭，该属性被合法赋值（非空，且最大长度为100的字符串）后打开提示功能。*/
        model.checkTipText = @"请勾选同意服务条款";
        
        //28、web协议界面导航返回图标(尺寸根据图片大小)
        model.webNavReturnImg = [UIImage imageNamed:@"close2"];
        //29、web协议界面导航标题字体属性设置
        model.webNavTitleAttrs = @{NSForegroundColorAttributeName: [UIColor redColor], NSFontAttributeName: [UIFont systemFontOfSize:16]};
        //30、web协议界面导航标题栏颜色
        model.webNavColor = [UIColor redColor];
        
        model.authViewBlock = ^(UIView *customView, CGRect numberFrame , CGRect loginBtnFrame,CGRect checkBoxFrame, CGRect privacyFrame) {
            /* 顺序 带+号的是添加的控件
             1+关闭按钮
             2+logo
             3+一键验证 label
             4.预取号label
             5.+carry Label
             6.登录按钮
             7.协议
             */
            CGFloat centerX = loginBtnFrame.origin.x + loginBtnFrame.size.width/2;
            CGFloat customViewW = customView.frame.size.width;
            CGFloat imageH = isSmallScreen ? 30 : 40;
            //1.右上角关闭按钮 由于区域比较小，设置为图片，然后上面搞一个btn
            UIImage *closeImage = [UIImage imageNamed:@"windowclose"];
            UIImageView *closeImageV = [[UIImageView alloc] initWithImage:closeImage];
            closeImageV.frame = CGRectMake(customView.frame.size.width - 20 - 20, (imageH-20)/2 + 10, 20, 20);
            [customView addSubview:closeImageV];
            UIButton *btn = [[UIButton alloc]initWithFrame:CGRectMake(0, 0, 50, 50)];
            btn.center = closeImageV.center;
            [btn addTarget:self action:@selector(dismissAuthVC) forControlEvents:(UIControlEventTouchUpInside)];
            [customView addSubview:btn];
            
            //2.logo imageV
            UIImageView *logoImageV = [[UIImageView alloc] initWithImage:[UIImage imageNamed:@"一键登录-logo"]];
            CGFloat logoImageVY = logoImageVy;
            logoImageV.frame = CGRectMake(0, logoImageVY, logoImageVWH, logoImageVWH);
            logoImageV.center = CGPointMake(centerX, logoImageV.center.y);
            [customView addSubview:logoImageV];
            
            //3.一键验证 Label
            CGFloat yanzhenlabelY = CGRectGetMaxY(logoImageV.frame) + marge;
            UILabel *yanzhenlabel = [[UILabel alloc] initWithFrame:CGRectMake(0, yanzhenlabelY, customViewW, yanzhenlabelH)];
            yanzhenlabel.center = CGPointMake(centerX, yanzhenlabel.center.y);
            yanzhenlabel.text = @"一键验证";
            yanzhenlabel.textColor = ssRGBHex(0xE6002D);
            yanzhenlabel.textAlignment = NSTextAlignmentCenter;
            [customView addSubview:yanzhenlabel];
            
            
            //5.carry Label
            CGFloat servylabelY = CGRectGetMaxY(numberFrame) + marge;
            UILabel *servylabel = [[UILabel alloc] initWithFrame:CGRectMake(0, servylabelY, customViewW, servylabelH)];
            servylabel.center = CGPointMake(centerX, servylabel.center.y);
            servylabel.text = [NSString stringWithFormat:@"%@提供认证服务", carrierStr];
            servylabel.textColor = ssRGBHex(0x959595);
            servylabel.font = [UIFont systemFontOfSize:14.0];
            servylabel.textAlignment = NSTextAlignmentCenter;
            [customView addSubview:servylabel];
//
//            customView.clipsToBounds = NO;
//            TestView *tView = [[TestView alloc] initWithFrame:CGRectMake(0, customView.bounds.size.height, 100, 100)];
//            UIButton *closeBtn = [UIButton buttonWithType:UIButtonTypeCustom];
//
//            closeBtn.frame = CGRectMake(20, 20, 60, 60);
//            [closeBtn setTitle:@"====" forState:UIControlStateNormal];
//            [closeBtn addTarget:self action:@selector(test) forControlEvents:UIControlEventTouchUpInside];
//            closeBtn.backgroundColor = UIColor.redColor;
//            [tView addSubview:closeBtn];
//            [customView addSubview:tView];
//
//            NSLog(@"==__00%@",customView);
            
        };
    }
    return model;
}

- (void)otherLoginBtnClick {
    [KSCProgressHUD showToastWithMessage:@"请开发者自行实现"];
}

@end
    
