//
//  KSCSDKLogin.h
//  KSCLoginSDK
//
//  Created by edz on 2020/12/22.
//  Copyright © 2020 ryw. All rights reserved.
//

#import <UIKit/UIKit.h>

NS_ASSUME_NONNULL_BEGIN
@class KSCCustomModel;

@interface KSCSDKLogin : NSObject
/**
 网络类型及运营商（双卡下，获取上网卡的运营商）
 "carrier"     运营商： 0.未知 / 1.中国移动 / 2.中国联通 / 3.中国电信
 "networkType" 网络类型： 0.无网络/ 1.数据流量 / 2.wifi / 3.数据+wifi
 @return  @{NSString : NSNumber}
 */
@property (nonatomic, class, readonly) NSDictionary<NSString *, NSNumber *> *networkInfo;

#pragma mark - ***********************  regist  ***********************
/**
 向SDK注册AppID
 (初始化内部的SDK)
 @discussion `AppID`通过后台注册获得
 @completion 注册成功回调 isRegist == YES
 */
+ (void)ksc_registerWithAppID:(NSString *)appID completion:(void(^)(BOOL isRegist))completion;

#pragma mark - ***********************  setting  ***********************
/**
 控制台日志输出控制（默认关闭）
 
 @param enable 开关参数  该方法必须在ksc_registerWithAppID之后调用
 */
+ (void)ksc_printConsoleEnable:(BOOL)enable;

/**
 设置超时

 @param timeout 超时  如果不设置，默认是8秒
 */
+ (void)ksc_setTimeoutInterval:(NSTimeInterval)timeout;

#pragma mark - ***********************  oneLogin  ***********************
/**
 获取预取号 也就是手机号码中间4位带星号  比如 ”187****3408“

 @param completion 回调
 */
+ (void)ksc_getPhoneNumberCompletion:(void(^)(NSDictionary *_Nonnull result))completion;

/**
 需要在获取预取号成功的回调中 执行该方法
 一键登录，获取到的token，可传给移动认证服务端获取完整手机号
 
 @param model 需要配置的Model属性（控制器必传）
 @param completion 回调
 */
+ (void)ksc_getAuthorizationWithModel:(KSCCustomModel *)model complete:(void (^)(id sender))completion;

/**
 关闭授权界面
 @param flag 动画开关
 @param completion 回调参数

 */
+ (void)ksc_ua_dismissViewControllerAnimated: (BOOL)flag completion: (void (^ __nullable)(void))completion;

#pragma mark - ***********************  onePass  ***********************
/**
 获取本机号码校验token

 @param completion 回调
 */
+ (void)ksc_mobileAuthCompletion:(void(^)(NSDictionary *_Nonnull result))completion;


/**
 删除取号缓存数据 + 重置网络开关（自定义按钮事件里dimiss授权界面需调用）
 
 @return YES：有缓存已执行删除操作，NO：无缓存不执行删除操作
 */
+ (BOOL)delectScrip;

#pragma mark - ***********************  判断网络方法  ***********************
/** 是否打开蜂窝*/
+ (BOOL)isOpenCellularNetwork;
/** 获取运营商 @"中国移动" 、@"中国联通" 、@"中国电信" 、@"未知网络"*/
+ (NSString *)carrierStr;

/** 获取运营商 CM移动 CT电信 CU联通"*/
+ (NSString *)carrierCharsStr;
@end

NS_ASSUME_NONNULL_END

